import { API } from "aws-amplify";
import { FetchBaseQueryError } from "@reduxjs/toolkit/query";

import { ContactEntry } from "types";

const contactsApi = "contactsappapi";

export async function createContactApi(
  newContact: ContactEntry
): Promise<{ data: any } | { error: FetchBaseQueryError }> {
  try {
    const data = await API.post(contactsApi, "/contacts", {
      body: newContact,
    });
    return { data: data };
  } catch (err) {
    return {
      error: err as FetchBaseQueryError,
    };
  }
}

export async function getAllContactApi(): Promise<
  { data: ContactEntry[] } | { error: FetchBaseQueryError }
> {
  try {
    const data = await API.get(contactsApi, "/contacts", {});
    return { data: data };
  } catch (err) {
    return {
      error: err as FetchBaseQueryError,
    };
  }
}

export async function getSingleContactApi(
  contactsid: string
): Promise<{ data: ContactEntry } | { error: FetchBaseQueryError }> {
  try {
    const data = await API.get(contactsApi, `/contacts/${contactsid}`, {});
    return { data };
  } catch (err) {
    return {
      error: err as FetchBaseQueryError,
    };
  }
}

export async function updateSingleContactApi(
  contact: ContactEntry
): Promise<{ data: any } | { error: FetchBaseQueryError }> {
  try {
    const data = await API.put(contactsApi, `/contacts/edit`, {
      body: contact,
    });
    return { data: data };
  } catch (err) {
    return {
      error: err as FetchBaseQueryError,
    };
  }
}

export async function updateIsFavoriteStatusContactApi(
  contact: ContactEntry
): Promise<{ data: any } | { error: FetchBaseQueryError }> {
  try {
    const data = await API.patch(
      contactsApi,
      `/contacts/updateFavorite/${contact.contactsid}`,
      {
        body: {
          isFavorite: contact.isFavorite,
          contactsid: contact.contactsid,
        },
      }
    );
    return { data: data };
  } catch (err) {
    return {
      error: err as FetchBaseQueryError,
    };
  }
}

export async function deleteSingleContactApi(
  contactId: string
): Promise<{ data: any } | { error: FetchBaseQueryError }> {
  try {
    const data = await API.del(
      contactsApi,
      `/contacts/delete/${contactId}`,
      {}
    );
    return { data: data };
  } catch (err) {
    return {
      error: err as FetchBaseQueryError,
    };
  }
}

export async function batchDeleteContactApi(
  ids: string[]
): Promise<{ data: any } | { error: FetchBaseQueryError }> {
  try {
    const data = await API.del(contactsApi, `/contacts/batch-remove`, {
      body: { contactsids: ids },
    });
    return { data: data };
  } catch (err) {
    return {
      error: err as FetchBaseQueryError,
    };
  }
}
