import { FetchBaseQueryError } from "@reduxjs/toolkit/query";
import { API } from "aws-amplify";

import { Label } from "types";

const contactsApi = "contactsappapi";

export async function createLabelApi(
  newLabel: Label
): Promise<{ data: any } | { error: FetchBaseQueryError }> {
  try {
    const data = await API.post(contactsApi, "/labels", {
      body: newLabel,
    });
    return { data: data };
  } catch (err) {
    return {
      error: err as FetchBaseQueryError,
    };
  }
}

export async function getAllLabelApi(): Promise<
  { data: Label[] } | { error: FetchBaseQueryError }
> {
  try {
    const data = await API.get(contactsApi, "/labels", {});
    return { data: data };
  } catch (err) {
    return {
      error: err as FetchBaseQueryError,
    };
  }
}

export async function deleteSingleLabelApi(
  labelId: string
): Promise<{ data: any } | { error: FetchBaseQueryError }> {
  try {
    const data = await API.del(
      contactsApi,
      `/labels/remove-label/${labelId}`,
      {}
    );
    return { data: data };
  } catch (err) {
    return {
      error: err as FetchBaseQueryError,
    };
  }
}
