import { api } from "../../api";
import {
  createContactApi,
  deleteSingleContactApi,
  getAllContactApi,
  getSingleContactApi,
  updateIsFavoriteStatusContactApi,
  updateSingleContactApi,
  batchDeleteContactApi,
} from "../asyncFunctions/contacts";

const contactsApiEndpoints = api.injectEndpoints({
  endpoints: (build) => ({
    createContact: build.mutation({
      queryFn: createContactApi,
      invalidatesTags: ["Contacts"],
    }),
    getAllContacts: build.query({
      queryFn: getAllContactApi,
      providesTags: ["Contacts"],
    }),
    getSingleContact: build.query({
      queryFn: getSingleContactApi,
      providesTags: ["Contacts"],
    }),
    updateSingleContact: build.mutation({
      queryFn: updateSingleContactApi,
      invalidatesTags: ["Contacts"],
    }),
    updateIsFavoriteStatusContact: build.mutation({
      queryFn: updateIsFavoriteStatusContactApi,
      invalidatesTags: ["Contacts"],
    }),
    deleteSingleContact: build.mutation({
      queryFn: deleteSingleContactApi,
      invalidatesTags: ["Contacts"],
    }),
    batchDeleteContact: build.mutation({
      queryFn: batchDeleteContactApi,
      invalidatesTags: ["Contacts"],
    }),
  }),
});

export const {
  useCreateContactMutation,
  useGetAllContactsQuery,
  useGetSingleContactQuery,
  useUpdateSingleContactMutation,
  useDeleteSingleContactMutation,
  useUpdateIsFavoriteStatusContactMutation,
  useBatchDeleteContactMutation,
} = contactsApiEndpoints;
