import Card from "@mui/material/Card";
import Typography from "@mui/material/Typography";
import Stack from "@mui/material/Stack";
import TextField from "@mui/material/TextField";
import Modal from "@mui/material/Modal";
import Button from "@mui/material/Button";
import { useState } from "react";
import { useCreateLabelMutation } from "api/labels";
import { Label } from "types";
import { v4 as uuidv4 } from "uuid";
import firstCharToUpperCase from "utils/firstCharToUpperCase";

interface Props {
  isOpen: boolean;
  handleClose: () => void;
}

export default function LabelModal({ isOpen, handleClose }: Props) {
  const [labelName, setLabelName] = useState<string>("");

  const [createLabel, { data, isError, error, isLoading }] =
    useCreateLabelMutation();

  const handleSubmit = () => {
    const newLabel: Label = {
      labelsid: uuidv4(),
      name: firstCharToUpperCase(labelName),
    };

    createLabel(newLabel);

    handleClose();
  };

  return (
    <Modal
      open={isOpen}
      aria-labelledby="modal-modal-title"
      aria-describedby="modal-modal-description"
      onClose={handleClose}
    >
      <Card
        sx={{
          position: "relative",
          alignItems: "center",
          top: "50%",
          left: "50%",
          transform: "translate(-50%, -50%)",
          width: "500px",
          padding: "20px",
          borderBottom: "solid 20px white",
        }}
      >
        <Stack gap={2}>
          <Typography id="modal-modal-title" variant="h6" component="h2">
            Create label
          </Typography>
          <TextField
            id="outlined-basic"
            label="Enter label name"
            variant="outlined"
            fullWidth
            value={labelName}
            onChange={(e) => setLabelName(e.target.value)}
          />

          <Stack direction="row" justifyContent="flex-end" gap={1}>
            <Button onClick={handleClose} variant="outlined">
              Cancel
            </Button>
            <Button onClick={handleSubmit} variant="contained">
              Save
            </Button>
          </Stack>
        </Stack>
      </Card>
    </Modal>
  );
}
