import Page from "components/Page";
import ContactForm from "./ContactForm";
import { ContactEntry, UnsavedContactEntry } from "types";
import { useCreateContactMutation } from "api/contacts";
import { useNavigate } from "react-router-dom";
import { CONTACTS_ROUTES } from "routes/paths";
import { v4 as uuidv4 } from "uuid";

export default function CreateContact() {
  const navigate = useNavigate();
  const [createContact] = useCreateContactMutation();

  const handleCreate = async (value: UnsavedContactEntry) => {
    const newContact: ContactEntry = {
      contactsid: uuidv4(),
      name: value.name,
      image: value.image,
      email: value.email,
      phone: value.phone,
      isFavorite: false,
      labels: value.labels,
    };

    console.log(newContact);

    createContact(newContact);

    navigate(CONTACTS_ROUTES.list);
  };

  const handleCancel = () => {
    navigate(CONTACTS_ROUTES.list);
  };

  return (
    <Page title="Create new contact">
      <ContactForm
        title="Create new contact"
        buttonName="Create"
        onCancel={handleCancel}
        onSubmit={handleCreate}
      />
    </Page>
  );
}
