import { useNavigate, useParams } from "react-router-dom";

import Page from "components/Page";
import ContactForm from "./ContactForm";

import {
  useGetSingleContactQuery,
  useUpdateSingleContactMutation,
} from "api/contacts";

import { skipToken } from "@reduxjs/toolkit/query";
import { ContactEntry, UnsavedContactEntry } from "types";
import { CONTACTS_ROUTES } from "routes/paths";

export default function EditContact() {
  const { id } = useParams();
  const navigate = useNavigate();

  const { data, isLoading } = useGetSingleContactQuery(id ?? skipToken);
  const [updateSingleContact] = useUpdateSingleContactMutation();

  if (isLoading) {
    return <>Loading</>;
  }

  if (!data) {
    return <>No Data</>;
  }

  const handleEdit = (value: UnsavedContactEntry) => {
    if (!data) return;
    console.log("value", data);
    const updateContact: ContactEntry = {
      contactsid: data.contactsid,
      name: value.name,
      phone: value.phone,
      image: value.image,
      email: value.email,
      labels: value.labels,
      isFavorite: value.isFavorite,
    };

    updateSingleContact(updateContact);

    navigate(CONTACTS_ROUTES.list);
  };

  const handleCancel = () => {
    navigate(CONTACTS_ROUTES.list);
  };

  return (
    <Page title="Edit contact">
      <ContactForm
        title="Edit contact"
        buttonName="Edit"
        onCancel={handleCancel}
        onSubmit={handleEdit}
        value={data}
      />
    </Page>
  );
}
