import {
  Authenticator,
  ThemeProvider,
  Theme,
  useTheme,
} from "@aws-amplify/ui-react";
import "@aws-amplify/ui-react/styles.css";
import Box from "@mui/material/Box";
import Typography from "@mui/material/Typography";

import Logo from "components/Logo";
import useResponsive from "hooks/useResponsive";
import { ReactNode } from "react";

type Props = {
  children: ReactNode;
};

export default function Login({ children }: Props) {
  const { tokens } = useTheme();
  const theme: Theme = {
    name: "ContactAppTheme",
    tokens: {
      colors: {
        background: {
          primary: {
            value: tokens.colors.white.value,
          },
          secondary: {
            value: tokens.colors.blue["10"].value,
          },
        },
        font: {
          interactive: {
            value: tokens.colors.blue["60"].value,
          },
        },
        brand: {
          primary: {
            "10": tokens.colors.blue["10"],
            "80": tokens.colors.blue["60"],
            "90": tokens.colors.blue["40"],
            "100": tokens.colors.blue["20"],
          },
        },
      },
      components: {
        tabs: {
          item: {
            _focus: {
              color: {
                value: tokens.colors.blue["100"].value,
              },
            },
            _hover: {
              color: {
                value: tokens.colors.blue["80"].value,
              },
            },
            _active: {
              color: {
                value: tokens.colors.blue["100"].value,
              },
            },
          },
        },
      },
    },
  };

  return (
    <ThemeProvider theme={theme}>
      <Box
        sx={{
          p: 2,
          display: "flex",
          flexDirection: "row-reverse",
        }}
      >
        <Logo />
        <Box
          sx={{
            display: "flex",
            justifyContent: "center",
            alignItems: "center",
            pr: 1,
          }}
        >
          <Typography variant="h6">Contacts App</Typography>
        </Box>
      </Box>

      <Authenticator>{children}</Authenticator>
    </ThemeProvider>
  );
}
