import { lazy } from "react";
import { useRoutes, Navigate } from "react-router-dom";

import DashboardLayout from "../layouts/mainLayout";
import { Loadable } from "./Loadable";
import { useAuthenticator } from "@aws-amplify/ui-react";

export default function Router() {
  const { user } = useAuthenticator((context) => [context.user]);

  const privateRoutes = [
    {
      path: "/",
      element: <DashboardLayout />,
      children: [
        {
          path: "/",
          element: <Navigate to="contacts/list" replace />,
        },
        {
          path: "contacts/list",
          element: <ContactsList />,
        },
        {
          path: "contacts/favorites",
          element: <ContactsList />,
        },
        {
          path: "contacts/labels/*",
          element: <ContactsList />,
        },
        {
          path: "contacts/new_contact",
          element: <CreateNewContact />,
        },
        {
          path: "contacts/edit_contact/:id",
          element: <EditContact />,
        },
      ],
    },
    {
      path: "*",
      element: <Page404 />,
      children: [
        { path: "404", element: <Page404 /> },
        { path: "*", element: <Navigate to="/404" replace /> },
      ],
    },
    { path: "*", element: <Navigate to="/404" replace /> },
  ];

  const publicRoutes = [
    {
      path: "*",
      element: <Page404 />,
      children: [
        { path: "404", element: <Page404 /> },
        { path: "*", element: <Navigate to="/404" replace /> },
      ],
    },
    { path: "*", element: <Navigate to="/404" replace /> },
  ];

  const routes = user ? privateRoutes : publicRoutes;

  return useRoutes(routes);
}

const ContactsList = Loadable(lazy(() => import("../pages/contactsList")));
const CreateNewContact = Loadable(
  lazy(() => import("../pages/contactsForm/CreateContact"))
);
const EditContact = Loadable(
  lazy(() => import("../pages/contactsForm/EditContact"))
);
const Page404 = Loadable(lazy(() => import("../components/Page404")));
